import {HttpClient} from '@angular/common/http';
import {AccesosService} from '../../services/acceso/acceso.service';
import {CerradurasService} from '../../services/cerradura/cerradura.service';
//import {Cerradura} from '../cerraduras/cerradura.model';
import {Nuki} from '../integraciones/nuki';
import {Portal} from '../integraciones/portal';

/**
 * Interfaz de genérico de Puerta para integrar cualquier tipo de cerradura
 */
export interface IPuerta {
  usuario_key: string;
  escena_key: string;
  cerradura_key: string;

  message: string;
  isRequesting: boolean;

  push(): boolean;
  open(): boolean;
  close(): boolean;
  getStatus(): string;
}

/**
 * Crea una puerta del tipo que corresponda según esté indicada en el cerradura
 * @param http Proveedor de http
 * @param ccs Proveedor de servicio de cerraduras
 * @param aas Proveedor de servicio de accesos
 * @param cerradura_key Identificador de la cerradura
 * @param usuario_key Identificador del usuario
 * @param escena_key Identificador de la escena
 */
export function createPuerta(http: HttpClient, ccs: CerradurasService, aas: AccesosService, cerradura_key: string, usuario_key: string, escena_key: string) {
  var promise = new Promise((resolve, reject) => {

    ccs.getCerraduraByKey(
      cerradura_key,
      done => {
        switch (done.tipo_key) {
          case 1:
            resolve(new Portal(http, ccs, aas, cerradura_key, usuario_key, escena_key));
            break;
          case 2:
            resolve(new Nuki(http, ccs, aas, cerradura_key, usuario_key, escena_key));
            break;
        }
      },
      fail => {
        reject('NO');
      }
    );
  });

  return promise;
}
