import { Component } from '@angular/core';
import { IonicPage, NavController, NavParams, Loading, LoadingController } from 'ionic-angular';
import { HttpClient } from '@angular/common/http';

import { GlobalData } from '../../app/globaldata';
import { CallNumber } from '@ionic-native/call-number';

// Modelos
import { Cerradura } from '../../models/cerraduras/cerradura.model';
import { Escena } from '../../models/escenas/escena.model';
//import { IPuerta, createPuerta } from '../../models/puertas/puerta';

// Servicios
import { EscenaService } from '../../services/escena/escena.service';
import { AccesosService } from '../../services/acceso/acceso.service';
import { CerradurasService } from '../../services/cerradura/cerradura.service';
import { createPuerta, IPuerta } from '../../models/puertas/puerta';
import { Usuario } from '../../models/usuarios/usuario.model';

@IonicPage()
@Component({
  selector: 'page-escena',
  templateUrl: 'escena.html'
})
export class EscenaPage {
  cerradurasList: Cerradura[];

  usuario: Usuario;

  GlobalData: any = GlobalData;
  escena_key: string;
  escena: Escena;

  puerta: Map<string, IPuerta>;
  loading: Loading;

  constructor(public loadingCtrl: LoadingController, public navCtrl: NavController, public navParams: NavParams, private ees: EscenaService, private ccs: CerradurasService, private aas: AccesosService, private http: HttpClient) {
    //, private callNumber: CallNumber
    console.log(NavParams.length);

    if (!this.navParams.get('escena')) {
      this.navCtrl.setRoot('HomePage');
    }
    this.escena_key = this.navParams.get('escena');
    this.puerta = new Map<string, IPuerta>();

    this.loading = this.loadingCtrl.create({
      spinner: 'dots',
      content: ''
    });
  }

  addPuerta(p: any) {
    if (!this.puerta.has(p.cerradura_key)) {
      this.puerta.set(p.cerradura_key, p);
    }
  }

  isRequesting(cerradura_key: string) {
    if (!this.puerta.has(cerradura_key)) {
      return false;
    }
    return this.puerta.get(cerradura_key).isRequesting;
  }

  actionCerradura(cerradura_key: string, action: string) {
    let p;
    createPuerta(this.http, this.ccs, this.aas, cerradura_key, GlobalData.getUsuario().key, this.escena_key)
      .then(
        val => {
          this.addPuerta(val);
          p = this.puerta.get(cerradura_key);
          if (p) {
            switch (action) {
              case 'push':
                p.push();
                break;
              case 'open':
                p.open();
                break;
              case 'close':
                p.close();
                break;
            }
          }
          //p.getStatus();
        },
        err => {
          console.error(err);
        }
      )
      .catch(reject => {
        console.log(reject);
      });

  }

  getMessage(cerradura_key: string) {
    if (this.puerta && this.puerta.get(cerradura_key)) {
      return this.puerta.get(cerradura_key).message;
    } else {
      return '';
    }
  }

  loadPage() {
    if (this.escena_key) {
      this.ees.getEscenaByKey(this.escena_key,

        (done) => {
          this.escena = done;
          
          //carga datos
          this.ccs.loadCerradurasByEscena(
            this.escena_key,
            done => {
              this.cerradurasList = done;
              this.cerradurasList.forEach((value, index) => {
                createPuerta(this.http, this.ccs, this.aas, value.key, GlobalData.getUsuario().key, this.escena_key).then(
                  val => {
                    this.addPuerta(val);
                    let p = this.puerta.get(value.key);
                    if (p) {
                      p.getStatus();
                    }
                  },
                  err => {
                    console.error(err);
                  }
                );
              });
              this.loading
                .dismiss()
                .then(t => {
                  //console.log('oh');
                })
                .catch(c => {
                  //console.log(c);
                });
            },
            fail => {
              console.log('fail', fail);
            }
          );

        },
        (fail) => {

        });
      //this.cerradurasList = this.ccs.getCerradurasByEscena(this.escena_key);
    } else {
      this.loading
        .dismiss()
        .then(t => {
          //console.log('oh');
        })
        .catch(c => {
          //console.log(c);
        });
      this.navCtrl.setRoot('HomePage');
    }
  }
  ionViewWillLoad() {
    this.loading.present();
    if (window.localStorage["uid"]) {
      this.loadPage();
    }
    else {
      this.loading
        .dismiss()
        .then(t => {
          //console.log('oh');
        })
        .catch(c => {
          //console.log(c);
        });
      this.navCtrl.setRoot('LoginPage');
    }
  }


  callAdministrator(phoneNumber: string) {

    window.location.href = "tel:" + phoneNumber;

    // this.callNumber.callNumber(phoneNumber, false)
    // .then(res => console.log('Launched dialer!', res))
    // .catch(err => console.log('Error launching dialer', err));
    // // this.callNumber.isCallSupported().then(() => {
    // //   this.callNumber.callNumber(phoneNumber, true)
    // //     .then(res => console.log('Launched dialer!', res))
    // //     .catch(err => console.log('Error launching dialer', err));
    // // });
  }

  createDump() {
    this.ees.createDump();
  }
}
