import { Component, ViewChild, ElementRef } from "@angular/core";
import {
  IonicPage,
  NavController,
  NavParams,
  ToastController,
  LoadingController,
  Loading,
  Platform
} from "ionic-angular";

import { GlobalData } from "../../app/globaldata";

// Modelos
import { Usuario, Escena_Acceso } from "../../models/usuarios/usuario.model";

// Servicios
import { UsuarioService } from "../../services/usuario/usuario.service";
import { EscenaService } from "../../services/escena/escena.service";

import {
  GoogleMaps,
  GoogleMap,
  GoogleMapsEvent,
  GoogleMapOptions,
  CameraPosition,
  MarkerOptions,
  Marker,
  LatLng,
  GoogleMapsAnimation,
  MyLocation
} from "@ionic-native/google-maps";
import { TipoCerradurasService } from "../../services/tipocerradura/tipocerradura.service";
import { Utils } from "../../app/utils";
import { animation } from "@angular/core/src/animation/dsl";
import { Geolocation } from "@ionic-native/geolocation";

@IonicPage()
@Component({
  selector: "page-home",
  templateUrl: "home.html"
})
export class HomePage {
  escenasList: Escena_Acceso[];
  usuario: Usuario;

  GlobalData: any = GlobalData;
  modo: string;
  loading: Loading;

  public map: GoogleMap;

  defaultView: string;
  utils: Utils = new Utils();
  latLng: LatLng;
  currentPosition: Marker;

  constructor(
    public loadingCtrl: LoadingController,
    public navCtrl: NavController,
    public navParams: NavParams,
    private toast: ToastController,
    private ees: EscenaService,
    private uus: UsuarioService,
    private ttccs: TipoCerradurasService,
    private platform: Platform,
    private geoLocation: Geolocation
  ) {
    this.utils = new Utils();
    this.defaultView =
      this.utils.getLocalStorageSetting("defaultView") || "list";
    this.modo = this.defaultView;

    this.loading = this.loadingCtrl.create({
      spinner: "dots",
      content: ""
    });

    this.platform.ready().then(() => {
      let mapOptions: GoogleMapOptions = {
        camera: {
          target: {
            lat: 43.0741904,
            lng: -89.3809802
          },
          zoom: 18,
          tilt: 30
        }
      };

      this.map = GoogleMaps.create("map");
      this.map
        .one(GoogleMapsEvent.MAP_READY)
        .then((data: any) => {
          
      this.loading = this.loadingCtrl.create({
        spinner: "dots",
        content: "Mapa cargado"
      });
          let myPosition: LatLng = new LatLng(42.8851668, -8.5391448);
          console.log("mapa cargado", data);
          this.map.moveCamera({ target: myPosition, zoom: 8 });
          this.map.setMyLocationButtonEnabled(false);

          this.geoLocation.watchPosition().subscribe(
            position => {
              this.latLng = new LatLng(
                position.coords.latitude,
                position.coords.longitude
              );

              this.map
                .addMarker({
                  icon: "red",
                  animation: "DROP",
                  position: this.latLng
                })
                .then(marker => {
                  if (this.currentPosition) this.currentPosition.remove();
                  this.currentPosition = marker;
                })
                .catch(e => {});
            },
            err => {
              console.log(err);
            }
          );

          this.map.getMyLocation().then((value:MyLocation) => {
            this.map.moveCamera(value);
          console.log("value", value);
          
        });
        })
        .catch(err => {
          console.log("error mapa", err);
        });
    });

    function addInvitation() {
      this.navCtrl.push("ActivatePage", {
        animation: true,
        direction: "fordward"
      });
    }
    // this.platform.ready().then(() => {

    //   let mapOptions: GoogleMapOptions = {
    //     camera: {
    //       target: {
    //         lat: 43.0741904,
    //         lng: -89.3809802
    //       },
    //       zoom: 18,
    //       tilt: 30
    //     }
    //   };

    // this.map = GoogleMaps.create('divmap', mapOptions);
    // this.map.one(GoogleMapsEvent.MAP_READY).then((data: any) => {
    //   let myPosition: LatLng = new LatLng(43.0741904, -89.3809802);
    //   this.map.animateCamera({ target: myPosition, zoom: 10 });
    //   console.log("mapa cargado");

    // }).catch(err => {
    //   console.log("error mapa", err);
    // })
    //this.loadMap();
    // })
  }

  setMode(mode: number) {
    switch (mode) {
      case 1:
        this.modo = "list";
        break;
      case 2:
        this.modo = "grid";
        break;
      case 3:
        this.modo = "map";
        break;
    }
  }
  loadMap() {
    let mapOptions: GoogleMapOptions = {
      camera: {
        target: {
          lat: 43.0741904,
          lng: -89.3809802
        },
        zoom: 18,
        tilt: 30
      }
    };

    this.map = GoogleMaps.create("map", mapOptions);

    // Wait the MAP_READY before using any methods.
    this.map.one(GoogleMapsEvent.MAP_READY).then(() => {
      console.log("Map is ready!");

      // Now you can use all methods safely.
      this.map
        .addMarker({
          title: "Ionic",
          icon: "blue",
          animation: "DROP",
          position: {
            lat: 43.0741904,
            lng: -89.3809802
          }
        })
        .then(marker => {
          marker.on(GoogleMapsEvent.MARKER_CLICK).subscribe(() => {
            alert("clicked");
          });
        });
    });
  }

  private loadPage() {
    //this.usuario = GlobalData.getUsuario();
    this.uus.getUsuarioByUID(
      window.localStorage["uid"],
      done => {
        this.usuario = done;

        if (this.usuario && this.usuario.key) {
          this.toast
            .create({
              message: `Bienvenido ${this.usuario.nombre}`,
              duration: 1000
            })
            .present();

          //carga escenas
          this.doLoad(null);
          this.loading.dismiss().then(() => {}, () => {});
        } else {
          this.loading.dismiss().then(
            () => {
              this.toast
                .create({
                  message: "No se encontró la información del usuario",
                  duration: 3000
                })
                .present();

              this.navCtrl.setRoot("LoginPage");
            },
            () => {}
          );
        }
      },
      fail => {
        console.log("fail", fail);
      }
    );
  }

  doLoad(event: any) {
    this.ees.loadEscenasByUsuario(
      this.usuario.key,
      done => {
        this.escenasList = done;

        this.addMarkers();
        //this.loading.dismiss().then(() => {}, () => {});
        if (event) event.complete();
      },
      fail => {
        console.log("fail", fail);
      }
    );
  }

  addMarkers() {
    this.escenasList.forEach((value: any, index) => {
      this.map
        .addMarker({
          title: `${value.descripcion}\n${value.direccion}`,
          icon: "yellow",
          animation: "DROP",
          position: {
            lat: value.latlon.lat,
            lng: value.latlon.lon
          }
        })
        .then(marker => {
          console.log("marcador");

          // marker.on(GoogleMapsEvent.MARKER_CLICK).subscribe(() => {
          //   alert("Marker Clicked");
          // });
        })
        .catch(e => {
          console.log("e", 2);
        });
    });

    // this.map.addMarker({
    //   position: {lat: 37.422359, lng: -122.084344},
    //   title: "Welecome to \n" +
    //          "Cordova GoogleMaps plugin for iOS and Android",
    //   snippet: "This plugin is awesome!",
    //   animation: GoogleMapsAnimation.BOUNCE
    // })
    // .then( function(marker) {

    //   // Show the info window
    //   marker.showInfoWindow();

    //   // Catch the click event
    //   marker.on(GoogleMapsEvent.INFO_CLICK).subscribe( function() {

    //     // To do something...
    //     alert("Hello world!");

    //   });
    // });
  }
  ionViewWillLoad() {
    //this.presentLoadingCustom();
    this.loading.present();
    if (window.localStorage["uid"]) {
      this.loadPage();
    } else {
      this.uus.getUsuarioByUID(
        window.localStorage["uid"],
        done => {
          GlobalData.usuario = done;
          this.loadPage();
        },
        fail => {
          console.error("error getUsuario", fail);
        }
      );
    }
  }

  isFilterable(): boolean {
    if (this.escenasList && this.escenasList.length > 6) return true;
    else return false;
  }
  gotoEscena(escena: string) {
    this.navCtrl.push("EscenaPage", { escena: escena });
  }

  createDumpEscenas() {
    this.ees.createDump().then(() => {
      this.navCtrl.setRoot("HomePage");
    });
  }

  createDumpUsuarios() {
    this.uus.createDump().then(() => {
      this.navCtrl.setRoot("HomePage");
    });
  }
  createDumpTiposCerraduras() {
    this.ttccs.createDump().then(() => {
      this.navCtrl.setRoot("HomePage");
    });
  }

  logout() {
    window.localStorage.removeItem("email");
    window.localStorage.removeItem("password");
    window.localStorage.removeItem("remember");
    window.localStorage.removeItem("uid");
    this.navCtrl.setRoot("LoginPage");
  }
}
