import { Component } from "@angular/core";
import {
  IonicPage,
  NavController,
  NavParams,
  ToastController,
  LoadingController,
  Loading,
  AlertController
} from "ionic-angular";
import { TranslateService } from "@ngx-translate/core";
import { AngularFireAuth } from "angularfire2/auth";
import { Usuario } from "../../models/usuarios/usuario.model";
import { AngularFireObject } from "angularfire2/database";

import { GlobalData } from "../../app/globaldata";
import { UsuarioService } from "../../services/usuario/usuario.service";

@IonicPage()
@Component({
  selector: "page-login",
  templateUrl: "login.html"
})
export class LoginPage {
  account: { email: string; password: string; uid: string, remember: boolean } = {
    email: "test@test.com",
    password: "testtest",
    uid: "",
    remember: false
  };
  usuario: AngularFireObject<Usuario>;

  loading: Loading;

  //GlobalData: any = GlobalData;

  // Our translated text strings
  private loginErrorString: string;
  User_Not_Found: string;
  User_Not_Found_Desc: string;


  constructor(
    public navCtrl: NavController,
    public toastCtrl: ToastController,
    public translateService: TranslateService,
    public navParams: NavParams,
    private afAuth: AngularFireAuth,
    private loadingCtrl: LoadingController,
    private alertCtrl: AlertController,
    private uus: UsuarioService

  ) {
    this.translateService.get('USER_NOT_FOUND').subscribe(value => this.User_Not_Found = value);
    this.translateService.get('USER_NOT_FOUND_DESC').subscribe(value => this.User_Not_Found_Desc = value);
    this.translateService.get('INVALID_LOGIN_PASSWORD').subscribe(value => this.loginErrorString = value);
  }

  // Attempt to login in through our User service
  async doLogin() {
    this.loading = this.loadingCtrl.create();

    this.loading.present();

    let t = this;
    try {
      console.log(this.account);
      this.afAuth.auth
        .signInWithEmailAndPassword(this.account.email, this.account.password)
        .then(function (firebaseUser) {
          // Success
          console.log(firebaseUser);

          //t.usuario = t.afDatabase.object<Usuario>(`Usuarios/${firebaseUser.uid}`);
          t.account["uid"] = firebaseUser.uid;

          t.uus.getUsuarioByUID(
            firebaseUser.uid,
            done => {
              t.usuario = done;
              GlobalData.usuario = done;

              window.localStorage.setItem("uid", firebaseUser.uid);
              window.localStorage.setItem("remember", t.account.remember.toString());
              if (t.account.remember) {
                window.localStorage.setItem("email", t.account.email);
                window.localStorage.setItem("password", t.account.password);
              }
              else {
                window.localStorage.setItem("email", null);
                window.localStorage.setItem("password", null);
              }
              t.loading.dismiss().then(() => {
                t.navCtrl.setRoot("HomePage", {
                  animation: true,
                  direction: "forward"
                });
              }, () => { });

            },
            fail => {
              console.error("error getUsuario", fail);
              t.loading.dismiss().then(() => { }, () => { });

            }
          );
        })
        .catch(function (error) {
          // Error Handling
          console.log(error);
          t.loading.dismiss().then(() => { }, () => { });
          let alert = t.alertCtrl.create({
            title: t.User_Not_Found,
            subTitle: error.code == "auth/user-not-found" ? t.User_Not_Found_Desc: t.loginErrorString,
            buttons: ['OK'],
          });
          alert.present();       
          });
      // console.log("result");
      //console.log(result);
      //  if(result){
      //        this.navCtrl.setRoot('HomePage');
      //      }
    } catch (e) {
      console.log("easdfsdf");
      console.log(e);
      t.loading.dismiss().then(() => { }, () => { });
    }
  }

  doForgotPassword() {
    this.navCtrl.push("ResetPage");
  }

  showLoading() {
    this.loading = this.loadingCtrl.create({
      content: "Please wait...",
      dismissOnPageChange: true
    });
    this.loading.present();
  }

  showError(text) {
    if (this.loading) {
      this.loading.dismiss();
    }

    let alert = this.alertCtrl.create({
      title: "Fail",
      subTitle: text,
      buttons: ["OK"]
    });
    alert.present(alert);
  }

  ionViewDidLoad() {
    console.log("ionViewDidLoad LoginPage");
  }
}
