import {Injectable} from '@angular/core';
import {AngularFireDatabase} from 'angularfire2/database';

// Modelos
import {Escena} from '../../models/escenas/escena.model';
import {Escena_Acceso} from '../../models/usuarios/usuario.model';

@Injectable()
export class EscenaService {
  private escenas = this.db.list<Escena>('Escenas');
  escena: Escena;

  constructor(private db: AngularFireDatabase) {}
  /*
  * Dump
  * */
  createDump() {
    let escena;
    escena = {
      nombre: 'Escena 1',
      descripcion: 'Casa de Barcelona',
      latlon: {lat: '4.5', lon: '8.4'},
      direccion: 'Avda. de la Libertad 2, 4º A',
      activo: true,
      cerraduras: [{cerradura_key: '-qQQQRQEWR', orden: 1}, {cerradura_key: '-lasflalsdfl', orden: 2}]
    } as Escena;
    this.escenas.push(escena);
    escena = {nombre: 'Escena 2', descripcion: 'Casa de Salamanca', latlon: {lat: '4.7', lon: '8.6'}, direccion: 'C/ de la fresa s/n', activo: true, cerraduras: [{cerradura_key: '-lasflalsdfl', orden: 1}]} as Escena;
    this.escenas.push(escena);
    escena = {nombre: 'Escena 3', descripcion: 'Apartamento Barcelona', latlon: {lat: '4.9', lon: '8.8'}, direccion: 'Diagonal, 123, 12 Derecha', activo: true, cerraduras: [{cerradura_key: '-wqerewradfs', orden: 1}]} as Escena;
    this.escenas.push(escena);
    escena = {nombre: 'Escena 4', descripcion: 'Piso Buenos Aires', latlon: {lat: '4.3', lon: '8.0'}, direccion: 'Avda. Romeo, 12202, 23º H', activo: true, cerraduras: []} as Escena;
    this.escenas.push(escena);
    escena = {nombre: 'Escena 5', descripcion: 'Cortijo', latlon: {lat: '4.1', lon: '8.2'}, direccion: 'Finca Maná', activo: false, cerraduras: []} as Escena;
    return this.escenas.push(escena);
  }

  /**
   * Obtiene las escenas permitidas (disponibles para su gestión) de un usuario
   * @param key Identificador del usuario
   * @param callbackDone función de llamada, en caso de éxito, con el resultado de la carga
   * @param callbackFail función de llamada, en caso de error, con el resultado del error
   */
  loadEscenasByUsuario(key: string, callbackDone: any, callbackFail: any) {
    let coleccion = new Array<Escena>();

    this.db
      .list(`Usuarios/${key}/escenas_acceso`)
      .snapshotChanges()
      .subscribe(
        snapDone => {
          snapDone.forEach(function(value, index, array) {
            var ea = value.payload.val();
            var escena_key = ea.escena_key;

            if (this.isBetweenValidDate(ea)) {
              this.db
                .object(`Escenas/${escena_key}`)
                .snapshotChanges()
                .subscribe(snapItem => {
                  if (
                    !coleccion.find(function(f) {
                      return f.key == ea.escena_key;
                    })
                  ) {
                    coleccion.push({key: snapItem.key, ...snapItem.payload.val(), escena_acceso: ea });
                  }
                  console.log('snapDone');
                  callbackDone(coleccion);
                });
            } else {
              var index = coleccion.findIndex(function(f) {
                return f.key == ea.escena_key;
              });
              if (index != -1) {
                coleccion = coleccion.slice(ea.escena_key, index);
                callbackDone(coleccion);
              }
            }
          }, this);
        },
        snapFail => {
          callbackFail(snapFail);
          console.log('snapFail');
        }
      );
  }

  /**
   * 
   * @param escena_acceso Escena_Acceso a comprobar si está entre una fecha válida 
   */
  isBetweenValidDate(escena_acceso: Escena_Acceso): boolean {
    let fecha_desde = '01/01/1900';
    let fecha_hasta = '31/12/2900';
    let hora_desde = '00:00';
    let hora_hasta = '23:59';

    if (escena_acceso.fecha_desde) {
      fecha_desde = escena_acceso.fecha_desde;
    }
    if (escena_acceso.fecha_hasta) {
      fecha_hasta = escena_acceso.fecha_hasta;
    }
    if (escena_acceso.hora_desde) {
      hora_desde = escena_acceso.hora_desde;
    }
    if (escena_acceso.hora_hasta) {
      hora_hasta = escena_acceso.hora_hasta;
    }

    let fd = fecha_desde.split('/');
    let fh = fecha_hasta.split('/');

    let strFechaDesde = fd[2] + '/' + fd[1] + '/' + fd[0] + ' ' + hora_desde;
    let strFechaHasta = fh[2] + '/' + fh[1] + '/' + fh[0] + ' ' + hora_hasta;

    let hora_actual = new Date();
    if (hora_actual > new Date(strFechaDesde) && hora_actual < new Date(strFechaHasta)) return true;
    else return false;
  }

  /**
   * Devuelve una escena a partir de su identificador
   * @param key Identificador de la escena
   * @param callbackDone función de llamada, en caso de éxito, con el resultado de la carga
   * @param callbackFail función de llamada, en caso de error, con el resultado del error
   */
  getEscenaByKey(key: string, callbackDone: any, callbackFail: any) {
    this.db
      .object(`Escenas/${key}`)
      .snapshotChanges()
      .subscribe(
        snapItem => {
          console.log('snapDone getEscenaByKey');
          let escena = {key: snapItem.key, ...snapItem.payload.val()};
          callbackDone(escena);
        },
        snapFail => {
          console.log('snapFail getEscenaByKey');
          callbackFail(snapFail);
        }
      );
  }

}
